c     ABAQUS User subroutine umatht
c This user subroutine implements graded elements with variable
c conductivity in ABAQUS. It can incorporate any functional
c variation of heat conductivity and specific heat.
c Ref: A. Sutradhar and G. H. Paulino, 2004, ‘A simple boundary element
c       method for potential problems in nonhomogeneous media’.
c       International Journal for Numerical Methods in Engineering
c				60, 2203-2230.
  subroutine umatht(u,dudt,dudg,flux,dfdt,dfdg,statev,temp,
  $    dtemp,dtemdx,time,dtime,predef,dpred,cmname,ntgrd,nstatv,
  $    props,nprops,coords,pnewdt,noel,npt,layer,kspt,kstep,kinc)
c
  include ’aba_param.inc’
  character*80 cmname
  dimension dudg(ntgrd),flux(ntgrd),dfdt(ntgrd),
  $    dfdg(ntgrd,ntgrd),statev(nstatv),dtemdx(ntgrd),time(2),
  $    predef(1),dpred(1),props(nprops),coords(3)
c               read in properties
c exponential
c beta=1.5
c cond=5.0*exp(2.0*beta*coords(3))
c trigonometric
c cond=5.0*(cos(coords(3))+4.68392*sin(coords(3)))**2.d0
c quadratic
  cond=20*(1+420.7*coords(3))**2.0
  specht=0.0
c               input specific heat
  dudt=specht
  deltu=dudt*dtemp
  u=u+deltu
c               input flux=-[k]*{dtemdx}
  do i=1, ntgrd
     flux(i)=-cond*dtemdx(i)
  end do
c               input isotropic conductivity
  do i=1, ntgrd
    dfdg(i,i)=-cond
  end do
  return
  end
